<!-- 
    @author Caesarovich
    @repository https://github.com/Caesarovich/rome-webshell

    This code is for educationnal purposes only.
    Malicious usage of this code will not hold the author responsible.
    Do not pentest without explicit permissions.

-->





<?php

/**
 * Некоторые вспомогательные функции для рендеринга html
 *
 * @author tommyknocker
 */
class Tools_HtmlHead {

    /**
     * Контейнер
     * @var array 
     */
    private static $headElements = array();

    /**
     * Подключение javascript-файлов
     * @param string|array $jsLinks ссылка или массив ссылок на файлы
     * @param string $jsLink
     */
    public static function addJS($jsLinks, $jsLink = null) {

        if (!$jsLinks) {
            return;
        }

        if (!is_array($jsLinks)) {
            $jsLinks = $jsLink ? array($jsLinks => $jsLink) : array($jsLinks);
        }

        foreach ($jsLinks as $index => $link) {
            $html = '<script type="text/javascript" src="' . $link . '"></script>';

            if (is_string($index)) {
                self::$headElements['js.' . $index] = $html;
            } else {
                self::$headElements[] = $html;
            }
        }
    }

    /*     * *
     * Добавление javascript-кода
     */

    public static function addJSInline($script) {
        self::$headElements[] = implode("\n", array('<script type="text/javascript">', $script, '</script>'));
    }

    /**
     * Добавление переменной js
     * @param string $name
     * @param mixed $variable
     */
    public static function addJsVar($name, $variable) {
        $result = (strpos($name, '.') === false ? 'var ' : '') . $name . ' = ';
        $determined = self::addJsVarDetermine($variable);
        self::addJSInline($result .= self::addJsHelper($variable) . ';');
    }

    /**
     * Формирование массива для js
     * @param type $array
     */
    private static function addJsHelper($array) {
        $result = "";

        if (is_array($array)) {

            $isNumericAndLinear = Parse::arrayIsNumeric($array) && array_merge($array) === $array;

            $result .= $isNumericAndLinear ? '[' : '{';

            $innerArray = array();

            foreach ($array as $key => $value) {
                $determinedValue = self::addJsVarDetermine($value);
                $result .= $isNumericAndLinear ? $determinedValue : self::addJsVarDetermine($key) . ':' . (!is_array($determinedValue) ? $determinedValue : '');

                if (is_array($determinedValue)) {
                    switch ($determinedValue['type']) {
                        case 'object':
                            $result .= self::addJsHelper(get_object_vars($value));
                            break;
                        case 'array':
                            $result .= self::addJsHelper($value);
                            break;
                    }
                } 

                $result .= ',' . ($isNumericAndLinear ? '' : "\n");
            }
            
            $result = rtrim($result, ",\n");

            $result .= $isNumericAndLinear ? ']' : '}';
        } else {
            $result .= self::addJsVarDetermine($array);
        }

        return $result;
    }

    /**
     * Returns correct javascript variable representation except to objects and arrays
     * @param mixed $variable
     * @return mixed
     */
    private static function addJsVarDetermine($variable) {
        switch (gettype($variable)) {
            case 'string':
                return '"' . $variable . '"';
                break;
            case 'boolean':
                return $variable ? 'true' : 'false';
                break;
            case 'integer':
            case 'double':
                return $variable;
                break;
            case 'NULL':
                return 'null';
                break;
            case 'array':
                return array('type' => 'array');
                break;
            case 'object':
                return array('type' => 'object');
                break;
        }

        return false;
    }

    /**
     * Добавление ссылки на таблицу стилей
     * @param string|array $styleLinks ссылка или массив ссылок на файлы
     * @param $styleLink
     */
    public static function addStyle($styleLinks, $styleLink = null) {
        if (!$styleLinks) {
            return;
        }

        if (!is_array($styleLinks)) {
            $styleLinks = $styleLink ? array($styleLinks => $styleLink) : array($styleLinks);
        }

        foreach ($styleLinks as $index => $link) {
            $html = '<link rel="stylesheet" type="text/css" href="' . $link . '"/>';

            if (is_string($index)) {
                self::$headElements['css.' . $index] = $html;
            } else {
                self::$headElements[] = $html;
            }
        }
    }

    /**
     * Добавление meta-заголовка
     * @param string $name
     * @param string $content
     */
    public static function addMeta($name, $content) {
        self::$headElements[] = '<meta name="' . $name . '" content="' . $content . '" />';
    }

    /**
     * Вывод элементов head
     * @param boolean $return
     */
    public static function out($return = false) {
        if ($return) {
            return self::$headElements;
        }

        echo implode("\n", self::$headElements);
    }
    

}
